/pol/ - No.1 Hitler movie in Germany? - Politically Incorrect - 4chan
Description: No.1 Hitler movie in Germany? - "/pol/ - Politically Incorrect" is 4chan's board for discussing and debating politics and current events.
Keywords: imageboard,politics,current events,debate,politically incorrect,Hitler,movie,Germany

[a / b / c / d / e / f / g / gif / h / hr / k / m / o / p / r / s / t / u / v / vg / vm / vmg / vr / vrpg / vst / w / wg] [i / ic] [r9k / s4s / vip / qa] [cm / hm / lgbt / y] [3 / aco / adv / an / bant / biz / cgl / ck / co / diy / fa / fit / gd / hc / his / int / jp / lit / mlp / mu / n / news / out / po / pol / pw / qst / sci / soc / sp / tg / toy / trv / tv / vp / vt / wsg / wsr / x / xs] [Settings] [Search] [Mobile] [Home]
Board
▼ Settings Mobile Home
/pol/ - Politically Incorrect

Return Catalog Bottom Refresh
Post a Reply
[Post a Reply]

Name |
Options |
Comment |
Verification | 4chan Pass users can bypass this verification. [Learn More] [Login]
Flag |
File |
Please read the Rules and FAQ before posting. There are 4 posters in this thread.

08/21/20 | New boards added: /vrpg/, /vmg/, /vst/ and /vm/
05/04/17 | New trial board added: /bant/ - International/Random
10/04/16 | New board for 4chan Pass users: /vip/ - Very Important Posts
[Hide] [Show All]

View Announcement

### Janitor applications are now closed. Thank you to everyone who applied!

[Return] [Catalog] [Bottom]

Anonymous (ID: BYagKQXI)
No.1 Hitler movie in Germany? 07/26/22(Tue)23:31:40 No. 388462123
File: hitler miss kromier.jpg (106 KB, 800x600)
106 KB JPG
No.1 Hitler movie in Germany? Anonymous (ID: BYagKQXI) 07/26/22(Tue)23:31:40 No. 388462123

> Apparently this movie smashed German box office records, and all the dialogue is ..NOT.. scripted.

>>
Anonymous (ID: yzu2QJHE)
07/26/22(Tue)23:33:23 No. 388462302
Anonymous (ID: yzu2QJHE) 07/26/22(Tue)23:33:23 No. 388462302

> >>388462123
> >>388462123
> >>388462123
> what movie?

>>
Anonymous (ID: xF49FJaT)
07/26/22(Tue)23:33:28 No. 388462314
Anonymous (ID: xF49FJaT) 07/26/22(Tue)23:33:28 No. 388462314

> >>388462123
> Funny movie but there was agenda with this film

>>
Anonymous (ID: e8uCKNk1)
07/26/22(Tue)23:34:47 No. 388462450
Anonymous (ID: e8uCKNk1) 07/26/22(Tue)23:34:47 No. 388462450

> >>389829992 →
> Look who's back.

[Return] [Catalog] [Top]

Post a Reply
Return Catalog Top Refresh

Delete Post: [File Only] Style:
[Disable Mobile View / Use Desktop Site]
[Enable Mobile View / Use Mobile Site]
All trademarks and copyrights on this page are owned by their respective parties. Images uploaded are the responsibility of the Poster. Comments are owned by the Poster.